#include <windows.h>
#include "gpioLib.h"
#include "CoProcLib.h"
#include "segmentdisplay.h"

extern volatile BOOL threadExit;

int wmain(void)
{
    DWORD procID = 0;
    DWORD versionMajor = 0;
    DWORD versionMinor = 0;
    DWORD versionBuild = 0;
	HANDLE threadHandle = 0;
    DWORD digit[4] = {1, 2, 3, 4};   ///< Data to be displayed.

    GPIOGetLibVersion(&versionMajor, &versionMinor, &versionBuild);   ///< Gets GPIO library version.
    printf("GPIOLib Version %d.%d.%d, \n",versionMajor, versionMinor, versionBuild);
    procID = getPROCID();            ///< Gets processor ID.
    switch(procID)
    {
        case TYPE_PXA270:
            printf("PXA270 detected\n");
            break;
        case TYPE_PXA320:
            printf("PXA320 detected\n");
            break;
        case TYPE_PXA300:
            printf("PXA300 detected\n");
            break;
        case TYPE_PXA310:
            printf("PXA310 detected\n");
            break;
        case TYPE_TEGRA2:
            printf("Tegra 2 detected\n");
            break;
        case TYPE_TEGRA3:
            printf("Tegra 3 detected\n");
            break;
        default:
            printf("Processor type unknown\n");
            return FALSE;
            break;
    }
    InitGPIOLib();                  ///< Initializes GPIO library.
    SegmentPinConfig();             ///< Configures GPIOs as input and output.
	/// Creates new thread for display.
	threadHandle = CreateThread(0, 0, (LPTHREAD_START_ROUTINE)SegmentDisplay, &digit, 0, 0);
	if (threadHandle == NULL)
	{
		printf("Unable to display the data, Error Code = %d\n", GetLastError());
	}
	else
	{
		printf("Displaying...\n");
	}
    printf("Press enter to stop the program and exit.");
	fflush(stdin);
	getchar();
	threadExit = TRUE;				///< To exit the thread.
	Sleep(20);						///< Time to wait for thread termination.
	CloseHandle(threadHandle);		///< Closes thread handle.
    DeInitGPIOLib();                ///< De-initializes GPIO library.
    return TRUE;
}